@@ -59,7 +59,7 @@ use base qw( Exporter DynaLoader );
 sub dl_load_flags { 0x01 } # global option
 
 BEGIN {
-  $VERSION = '2.03';
+  $VERSION = '2.04';
   bootstrap Net::Silk $VERSION;
 }
 
@@ -72,8 +72,6 @@ use constant SILK_IPADDR_CLASS          => 'Net::Silk::IPAddr';
 use constant SILK_IPV4ADDR_CLASS        => 'Net::Silk::IPv4Addr';
 use constant SILK_IPV6ADDR_CLASS        => 'Net::Silk::IPv6Addr';
 use constant SILK_RANGE_CLASS           => 'Net::Silk::Range';
-use constant SILK_RANGE_IP_CLASS        => 'Net::Silk::Range::IP';
-use constant SILK_RANGE_PP_CLASS        => 'Net::Silk::Range::ProtoPort';
 use constant SILK_CIDR_CLASS            => 'Net::Silk::CIDR';
 use constant SILK_PROTOPORT_CLASS       => 'Net::Silk::ProtoPort';
 use constant SILK_TCPFLAGS_CLASS        => 'Net::Silk::TCPFlags';
@@ -149,8 +147,6 @@ BEGIN {
     SILK_PMAP_ITER_CLASS
 
     SILK_RANGE_CLASS
-    SILK_RANGE_IP_CLASS
-    SILK_RANGE_PP_CLASS
     SILK_CIDR_CLASS
 
     SILK_SITE_REPO_ITER_CLASS
