@@ -1046,15 +1046,18 @@ sub new {
   defined $item || croak "inner item required";
   return $item if UNIVERSAL::isa($item => SILK_BAG_CLASS) ||
                   UNIVERSAL::isa($item => $class);
-  if (UNIVERSAL::isa($item => 'ARRAY')) {
-    my $h = {};
-    ++$h->{$_} foreach @$item;
-    $item = $h;
-  }
-  if (UNIVERSAL::isa($item => 'HASH')) {
-    my $self = { item => $item };
-    bless($self, 'Net::Silk::VirtualBag::Hash');
-    return $self;
+  if (! UNIVERSAL::isa($item => SILK_RANGE_CLASS) &&
+      ! UNIVERSAL::isa($item => SILK_CIDR_CLASS)) {
+    if (UNIVERSAL::isa($item => 'ARRAY')) {
+      my $h = {};
+      ++$h->{$_} foreach @$item;
+      $item = $h;
+    }
+    if (UNIVERSAL::isa($item => 'HASH')) {
+      my $self = { item => $item };
+      bless($self, 'Net::Silk::VirtualBag::Hash');
+      return $self;
+    }
   }
   return undef unless
     UNIVERSAL::can($item => 'cardinality') &&
