@@ -186,6 +186,11 @@ sub get {
     ||= $self->_val_to_label($val, $Attr{$self}->[MAX_LABEL_SIZE]);
 }
 
+sub get_range {
+  my $self = shift;
+  SILK_RANGE_CLASS->new($self->_get_range(@_));
+}
+
 sub _fh_iter {
   my $self = shift;
   my $iter = ($Attr{$self} ||= [])->[FH_ITER] ||= $self->iter;
@@ -208,17 +213,15 @@ sub iter {
   my $label = ($Attr{$self} ||= [])->[LABELS] ||= {};
   my($next, $range_class);
   if ($self->_is_ipaddr) {
-    $range_class = SILK_RANGE_IP_CLASS;
     $next = \&Net::Silk::Pmap::iter_xs::next_ip;
   }
   else {
-    $range_class = SILK_RANGE_PP_CLASS;
     $next = \&Net::Silk::Pmap::iter_xs::next_pp;
   }
   my @items;
   sub {
     while (my @block = $next->($iter)) {
-      my $r = $range_class->new($block[0], $block[1]);
+      my $r = SILK_RANGE_CLASS->new($block[0], $block[1]);
       my $val = $block[2];
       $val = $label->{$val}
         ||= Net::Silk::Pmap::_val_to_label($self, $val,
@@ -236,28 +239,6 @@ sub iter {
 
 *iter_ranges = *iter_pmap = \&iter;
 
-sub iter_cidr {
-  my $self = shift;
-  my $iter = $self->iter;
-  my($block, @cidr, @items);
-  sub {
-    while ($block ||= $iter->()) {
-      @cidr = $block->[0]->as_cidr unless @cidr;
-      while (my $c = shift @cidr) {
-        if (wantarray) {
-          push(@items, [$c, $block->[1]]);
-          next;
-        }
-        else {
-          return [$c, $block->[1]];
-        }
-      }
-      $block = undef;
-    }
-    return @items if wantarray;
-  };
-}
-
 sub iter_vals {
   my $self = shift;
   my $max  = $self->val_count - 1;
@@ -486,6 +467,36 @@ sub _parse_range {
   return $range;
 }
 
+sub get_cidr {
+  my $self = shift;
+  my $key  = shift;
+  for my $cidr ($self->get_range($key)->as_cidr) {
+    return $cidr if $cidr->contains($key);
+  }
+}
+
+sub iter_cidr {
+  my $self = shift;
+  my $iter = $self->iter_ranges;
+  my($block, @cidr, @items);
+  sub {
+    while ($block ||= $iter->()) {
+      @cidr = $block->[0]->as_cidr unless @cidr;
+      while (my $c = shift @cidr) {
+        if (wantarray) {
+          push(@items, [$c, $block->[1]]);
+          next;
+        }
+        else {
+          return [$c, $block->[1]];
+        }
+      }
+      $block = undef;
+    }
+    return @items if wantarray;
+  };
+}
+
 ###
 
 package Net::Silk::Pmap::IPv6;
@@ -570,7 +581,7 @@ Net::Silk::Pmap - SiLK Prefix Map interface
 
   while (my $ip = <$addys>) {
     my $svc = $labels{$ip}; # or $labels->get($ip)
-    print "$ip $svc" unless $svc eq 'unknown';
+    print "$ip $svc" unless $svc eq 'UNKNOWN';
   }
 
   while (my $entry = <$labels>) {
@@ -590,6 +601,7 @@ Net::Silk::Pmap - SiLK Prefix Map interface
   );
   $pm->add("1.2.2.1", "1.2.3.255" => "lab servers");
   $pm->add("5.6.7.8/27" => "wombat enclave");
+  $pm->add("10.11.1.1-10.11.1.255" => "front office");
   $pm->save("my_addys.pmap");
 
 =head1 DESCRIPTION
@@ -654,8 +666,9 @@ of either.
 
 =item get_range($key)
 
-Return the range containing the given key as a list containing hi and
-low L<Net::Silk::IPAddr> or L<Net::Silk::ProtoPort> values.
+Return a L<Net::Silk::Range> object representing the range containing
+the given key with high and low L<Net::Silk::IPAddr> or
+L<Net::Silk::ProtoPort> values.
 
 =item add($range_or_cidr, $label)
 
@@ -710,7 +723,7 @@ labels to a list of all the proto/port ranges for that label.
 =head1 IPv4 AND IPv6 METHODS
 
 The L<Net::Silk::Pmap::IPv4> and L<Net::Silk::Pmap::IPv6> classes have
-an additional iterator type:
+some additional methods specific to IP addresses:
 
 =over
 
@@ -720,6 +733,11 @@ Returns a sub ref that when invoked returns an array ref containing a
 L<Net::Silk::CIDR> block along with its associated label. The iterator
 will return all pairs when invoked in list context.
 
+=item get_cidr($key)
+
+Return a L<Net::Silk::CIDR> object representing the block containing the
+given IP address.
+
 =back
 
 =head1 OPERATORS
